==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythbrowser/i18n/mythbrowser_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Sélectionnez un groupe ou un site à afficher</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>Paramètres des signets de Mythbrowser</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>Appuyez sur le bouton &apos;Nouveau Signet&apos; pour ajouter un nouveau site/groupe 
Appuyez sur ESPACE/ENTREE afin de supprimer l&apos;élément sélectionné de la liste</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Navigateur:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Efface les barres de défilement</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Faire défiler la page</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Vitesse de défilement:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Nouveau Signet</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Ajouter un nouveau site Web</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Terminer</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>Add New Website</source>
        <translation>Ajouter un nouveau site web</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Groupe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>         Back         </source>
        <translation>        Arrière        </translation>
    </message>
    <message>
        <source>       Next Tab       </source>
        <translation>    Onglet Suivant    </translation>
    </message>
    <message>
        <source>       Prev Tab       </source>
        <translation>   Onglet Précédent   </translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>Ajouter le lien aux signets</translation>
    </message>
    <message>
        <source>       zoom Out       </source>
        <translation type="obsolete">       Dézoomer       </translation>
    </message>
    <message>
        <source>       zoom In        </source>
        <translation type="obsolete">        Zoomer         </translation>
    </message>
    <message>
        <source>MythBrowser Menu</source>
        <translation>Menu de MythBrowser</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation>Entrer l&apos;URL</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>      Remove Tab      </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>       Zoom Out       </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>       Zoom In        </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythbrowser/i18n/mythbrowser_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Sélectionnez un groupe ou un site à afficher</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>Paramètres des signets de Mythbrowser</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>Appuyez sur le bouton &apos;Nouveau Signet&apos; pour ajouter un nouveau site/groupe 
Appuyez sur ESPACE/ENTREE afin de supprimer l&apos;élément sélectionné de la liste</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Navigateur:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Efface les barres de défilement</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Faire défiler la page</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Vitesse de défilement:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Nouveau Signet</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Ajouter un nouveau site Web</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Terminer</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>Add New Website</source>
        <translation>Ajouter un nouveau site web</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Groupe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>         Back         </source>
        <translation type="obsolete">        Arrière        </translation>
    </message>
    <message>
        <source>       Next Tab       </source>
        <translation type="obsolete">    Onglet Suivant    </translation>
    </message>
    <message>
        <source>       Prev Tab       </source>
        <translation type="obsolete">   Onglet Précédent   </translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>Ajouter le lien aux signets</translation>
    </message>
    <message>
        <source>       zoom Out       </source>
        <translation type="obsolete">       Dézoomer       </translation>
    </message>
    <message>
        <source>       zoom In        </source>
        <translation type="obsolete">        Zoomer         </translation>
    </message>
    <message>
        <source>MythBrowser Menu</source>
        <translation>Menu de MythBrowser</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation>Entrer l&apos;URL</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prev Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add New Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished">Groupe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished">Description:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation type="unfinished">URL:</translation>
    </message>
</context>
</TS>
